package com.ruoyi.project.ticket.domain;

import com.ruoyi.framework.web.domain.BaseEntity;

import java.util.List;

public class PermitRelation extends BaseEntity {
    private Long id;
    private Long aId;
    private Long cId;
    private Long bpId;
    private String bWorkContent;
    private String cbWorkContent;
    private String hVNoOne;
    private String chVNoOne;
    private String delayCount;
    private String delayNo;
    private String wordUrl;

    private String pdfUrl;
    private List<PermitRelation> children;

    private Long permitId;
    private String permitType;
    private Long permitStatus;

    public Long getBpId() {
        return bpId;
    }

    public void setBpId(Long bpId) {
        this.bpId = bpId;
    }

    public String getWordUrl() {
        return wordUrl;
    }

    public void setWordUrl(String wordUrl) {
        this.wordUrl = wordUrl;
    }

    public Long getPermitId() {
        return permitId;
    }

    public void setPermitId(Long permitId) {
        this.permitId = permitId;
    }

    public String getPermitType() {
        return permitType;
    }

    public void setPermitType(String permitType) {
        this.permitType = permitType;
    }

    public Long getPermitStatus() {
        return permitStatus;
    }

    public void setPermitStatus(Long permitStatus) {
        this.permitStatus = permitStatus;
    }

    public String getDelayCount() {
        return delayCount;
    }

    public void setDelayCount(String delayCount) {
        this.delayCount = delayCount;
    }

    public String getDelayNo() {
        return delayNo;
    }

    public void setDelayNo(String delayNo) {
        this.delayNo = delayNo;
    }

    public List<PermitRelation> getChildren() {
        return children;
    }

    public void setChildren(List<PermitRelation> children) {
        this.children = children;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getaId() {
        return aId;
    }

    public void setaId(Long aId) {
        this.aId = aId;
    }

    public Long getcId() {
        return cId;
    }

    public void setcId(Long cId) {
        this.cId = cId;
    }

    public String getbWorkContent() {
        return bWorkContent;
    }

    public void setbWorkContent(String bWorkContent) {
        this.bWorkContent = bWorkContent;
    }

    public String getCbWorkContent() {
        return cbWorkContent;
    }

    public void setCbWorkContent(String cbWorkContent) {
        this.cbWorkContent = cbWorkContent;
    }

    public String gethVNoOne() {
        return hVNoOne;
    }

    public void sethVNoOne(String hVNoOne) {
        this.hVNoOne = hVNoOne;
    }

    public String getChVNoOne() {
        return chVNoOne;
    }

    public void setChVNoOne(String chVNoOne) {
        this.chVNoOne = chVNoOne;
    }
    public String getPdfUrl() {
        return pdfUrl;
    }

    public void setPdfUrl(String pdfUrl) {
        this.pdfUrl = pdfUrl;
    }
}
